## dbt-adapters 1.15 - May 19, 2025

### Features

- Overridable default query comment append behavior ([#1065](https://github.com/dbt-labs/dbt-adapters/issues/1065))

### Fixes

- Respect the `limit` config when storing test failures ([#373](https://github.com/dbt-labs/dbt-adapters/issues/373))
- Keep `limit` as a required parameter in `get_test_sql` ([#1051](https://github.com/dbt-labs/dbt-adapters/issues/1051))
- Fix an issue with snapshots in new_record mode when check columns are used. ([#1068](https://github.com/dbt-labs/dbt-adapters/issues/1068))

### Under the Hood

- Keep table and column metadata as strings ([#1056](https://github.com/dbt-labs/dbt-adapters/issues/1056))
